@@ -9,32 +9,38 @@
 
 #include "kdialogjobuidelegate.h"
 
-#include <QWidget>
-#include <QQueue>
 #include <QPointer>
+#include <QQueue>
+#include <QWidget>
 
-#include <KMessageBox>
 #include <KJob>
+#include <KMessageBox>
 #include <kjobwidgets.h>
 
 #include <config-kjobwidgets.h>
 #if HAVE_X11
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
 #include <QX11Info>
 #endif
+#endif
+
+enum DialogType { ErrorDialog, WarningDialog };
 
 struct MessageBoxData {
     QWidget *widget;
-    KMessageBox::DialogType type;
+    DialogType type = ErrorDialog;
     QString msg;
 };
 
-class Q_DECL_HIDDEN KDialogJobUiDelegate::Private : public QObject
+class KDialogJobUiDelegatePrivate : public QObject
 {
     Q_OBJECT
 public:
-    explicit Private(QObject *parent = nullptr);
-    virtual ~Private();
-    void queuedMessageBox(QWidget *widget, KMessageBox::DialogType type, const QString &msg);
+    explicit KDialogJobUiDelegatePrivate(QObject *parent = nullptr);
+    ~KDialogJobUiDelegatePrivate() override;
+    void queuedMessageBox(QWidget *widget, DialogType type, const QString &msg);
 
     QWidget *window;
 
@@ -43,22 +49,22 @@ public Q_SLOTS:
 
 private:
     bool running;
-    QQueue<QSharedPointer<MessageBoxData> > queue;
+    QQueue<QSharedPointer<MessageBoxData>> queue;
 };
 
-KDialogJobUiDelegate::Private::Private(QObject *parent)
+KDialogJobUiDelegatePrivate::KDialogJobUiDelegatePrivate(QObject *parent)
     : QObject(parent)
     , window(nullptr)
     , running(false)
 {
 }
 
-KDialogJobUiDelegate::Private::~Private()
+KDialogJobUiDelegatePrivate::~KDialogJobUiDelegatePrivate()
 {
     queue.clear();
 }
 
-void KDialogJobUiDelegate::Private::next()
+void KDialogJobUiDelegatePrivate::next()
 {
     if (queue.isEmpty()) {
         running = false;
@@ -67,48 +73,52 @@ void KDialogJobUiDelegate::Private::next()
 
     QSharedPointer<MessageBoxData> data = queue.dequeue();
 
-    //kmessagebox starts a new event loop which can cause this to get deleted
-    //https://bugs.kde.org/show_bug.cgi?id=356321#c16
-    QPointer<KDialogJobUiDelegate::Private> thisGuard(this);
-    KMessageBox::messageBox(data->widget, data->type, data->msg);
+    // kmessagebox starts a new event loop which can cause this to get deleted
+    // https://bugs.kde.org/show_bug.cgi?id=356321#c16
+    QPointer<KDialogJobUiDelegatePrivate> thisGuard(this);
+
+    switch (data->type) {
+    case ErrorDialog:
+        KMessageBox::error(data->widget, data->msg);
+        break;
+    case WarningDialog:
+        KMessageBox::information(data->widget, data->msg);
+        break;
+    };
 
     if (!thisGuard) {
         return;
     }
 
-    QMetaObject::invokeMethod(this, "next", Qt::QueuedConnection);
+    QMetaObject::invokeMethod(this, &KDialogJobUiDelegatePrivate::next, Qt::QueuedConnection);
 }
 
-void KDialogJobUiDelegate::Private::queuedMessageBox(QWidget *widget, KMessageBox::DialogType type, const QString &msg)
+void KDialogJobUiDelegatePrivate::queuedMessageBox(QWidget *widget, DialogType type, const QString &msg)
 {
-    QSharedPointer<MessageBoxData> data(new MessageBoxData);
-    data->type = type;
-    data->widget = widget;
-    data->msg = msg;
+    QSharedPointer<MessageBoxData> data(new MessageBoxData{widget, type, msg});
 
     queue.enqueue(data);
 
     if (!running) {
         running = true;
-        QMetaObject::invokeMethod(this, "next", Qt::QueuedConnection);
+        QMetaObject::invokeMethod(this, &KDialogJobUiDelegatePrivate::next, Qt::QueuedConnection);
     }
 }
 
 KDialogJobUiDelegate::KDialogJobUiDelegate()
-    : KJobUiDelegate(), d(new KDialogJobUiDelegate::Private)
+    : KJobUiDelegate()
+    , d(new KDialogJobUiDelegatePrivate)
 {
 }
 
 KDialogJobUiDelegate::KDialogJobUiDelegate(KJobUiDelegate::Flags flags, QWidget *window)
-    : KJobUiDelegate(flags), d(new KDialogJobUiDelegate::Private)
+    : KJobUiDelegate(flags)
+    , d(new KDialogJobUiDelegatePrivate)
 {
     d->window = window;
 }
 
-KDialogJobUiDelegate::~KDialogJobUiDelegate()
-{
-    delete d;
-}
+KDialogJobUiDelegate::~KDialogJobUiDelegate() = default;
 
 bool KDialogJobUiDelegate::setJob(KJob *job)
 {
@@ -153,15 +163,16 @@ unsigned long KDialogJobUiDelegate::userTimestamp() const
 void KDialogJobUiDelegate::showErrorMessage()
 {
     if (job()->error() != KJob::KilledJobError) {
-        d->queuedMessageBox(window(), KMessageBox::Error, job()->errorString());
+        d->queuedMessageBox(window(), ErrorDialog, job()->errorString());
     }
 }
 
-void KDialogJobUiDelegate::slotWarning(KJob * /*job*/, const QString &plain, const QString &/*rich*/)
+void KDialogJobUiDelegate::slotWarning(KJob * /*job*/, const QString &plain, const QString & /*rich*/)
 {
     if (isAutoWarningHandlingEnabled()) {
-        d->queuedMessageBox(window(), KMessageBox::Information, plain);
+        d->queuedMessageBox(window(), WarningDialog, plain);
     }
 }
 
 #include "kdialogjobuidelegate.moc"
+#include "moc_kdialogjobuidelegate.cpp"
